==> gr-audio-oss-0.1.tar.gz: gr-audio-oss-0.1/src/audio_oss.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _audio_oss

def _swig_setattr(self,class_type,name,value):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    self.__dict__[name] = value

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


class audio_oss_sink_sptr(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_sink_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_sink_sptr, name)
    def __repr__(self):
        return "<C boost::shared_ptr<(audio_oss_sink)> instance at %s>" % (self.this,)
    def __init__(self, *args):
        _swig_setattr(self, audio_oss_sink_sptr, 'this', _audio_oss.new_audio_oss_sink_sptr(*args))
        _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 1)
    def __deref__(*args): return _audio_oss.audio_oss_sink_sptr___deref__(*args)
    def name(*args): return _audio_oss.audio_oss_sink_sptr_name(*args)
    def input_signature(*args): return _audio_oss.audio_oss_sink_sptr_input_signature(*args)
    def output_signature(*args): return _audio_oss.audio_oss_sink_sptr_output_signature(*args)
    def unique_id(*args): return _audio_oss.audio_oss_sink_sptr_unique_id(*args)
    def detail(*args): return _audio_oss.audio_oss_sink_sptr_detail(*args)
    def set_detail(*args): return _audio_oss.audio_oss_sink_sptr_set_detail(*args)
    def __del__(self, destroy=_audio_oss.delete_audio_oss_sink_sptr):
        try:
            if self.thisown: destroy(self)
        except: pass

class audio_oss_sink_sptrPtr(audio_oss_sink_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_oss_sink_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 0)
        _swig_setattr(self, audio_oss_sink_sptr,self.__class__,audio_oss_sink_sptr)
_audio_oss.audio_oss_sink_sptr_swigregister(audio_oss_sink_sptrPtr)


audio_oss_sink_block = _audio_oss.audio_oss_sink_block
audio_oss_sink_sptr.block = lambda self: audio_oss_sink_block (self)
audio_oss_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


sink = _audio_oss.sink
class audio_oss_source_sptr(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_source_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_source_sptr, name)
    def __repr__(self):
        return "<C boost::shared_ptr<(audio_oss_source)> instance at %s>" % (self.this,)
    def __init__(self, *args):
        _swig_setattr(self, audio_oss_source_sptr, 'this', _audio_oss.new_audio_oss_source_sptr(*args))
        _swig_setattr(self, audio_oss_source_sptr, 'thisown', 1)
    def __deref__(*args): return _audio_oss.audio_oss_source_sptr___deref__(*args)
    def name(*args): return _audio_oss.audio_oss_source_sptr_name(*args)
    def input_signature(*args): return _audio_oss.audio_oss_source_sptr_input_signature(*args)
    def output_signature(*args): return _audio_oss.audio_oss_source_sptr_output_signature(*args)
    def unique_id(*args): return _audio_oss.audio_oss_source_sptr_unique_id(*args)
    def detail(*args): return _audio_oss.audio_oss_source_sptr_detail(*args)
    def set_detail(*args): return _audio_oss.audio_oss_source_sptr_set_detail(*args)
    def __del__(self, destroy=_audio_oss.delete_audio_oss_source_sptr):
        try:
            if self.thisown: destroy(self)
        except: pass

class audio_oss_source_sptrPtr(audio_oss_source_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_oss_source_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_source_sptr, 'thisown', 0)
        _swig_setattr(self, audio_oss_source_sptr,self.__class__,audio_oss_source_sptr)
_audio_oss.audio_oss_source_sptr_swigregister(audio_oss_source_sptrPtr)


audio_oss_source_block = _audio_oss.audio_oss_source_block
audio_oss_source_sptr.block = lambda self: audio_oss_source_block (self)
audio_oss_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


source = _audio_oss.source

==> gr-audio-oss-0.3.tar.gz: gr-audio-oss-0.3/src/audio_oss.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _audio_oss

def _swig_setattr(self,class_type,name,value):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    self.__dict__[name] = value

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


class audio_oss_sink_sptr(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_sink_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_sink_sptr, name)
    def __repr__(self):
        return "<C boost::shared_ptr<(audio_oss_sink)> instance at %s>" % (self.this,)
    def __init__(self, *args):
        _swig_setattr(self, audio_oss_sink_sptr, 'this', _audio_oss.new_audio_oss_sink_sptr(*args))
        _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 1)
    def __deref__(*args): return _audio_oss.audio_oss_sink_sptr___deref__(*args)
    def name(*args): return _audio_oss.audio_oss_sink_sptr_name(*args)
    def input_signature(*args): return _audio_oss.audio_oss_sink_sptr_input_signature(*args)
    def output_signature(*args): return _audio_oss.audio_oss_sink_sptr_output_signature(*args)
    def unique_id(*args): return _audio_oss.audio_oss_sink_sptr_unique_id(*args)
    def output_multiple(*args): return _audio_oss.audio_oss_sink_sptr_output_multiple(*args)
    def relative_rate(*args): return _audio_oss.audio_oss_sink_sptr_relative_rate(*args)
    def check_topology(*args): return _audio_oss.audio_oss_sink_sptr_check_topology(*args)
    def detail(*args): return _audio_oss.audio_oss_sink_sptr_detail(*args)
    def set_detail(*args): return _audio_oss.audio_oss_sink_sptr_set_detail(*args)
    def __del__(self, destroy=_audio_oss.delete_audio_oss_sink_sptr):
        try:
            if self.thisown: destroy(self)
        except: pass

class audio_oss_sink_sptrPtr(audio_oss_sink_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_oss_sink_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 0)
        _swig_setattr(self, audio_oss_sink_sptr,self.__class__,audio_oss_sink_sptr)
_audio_oss.audio_oss_sink_sptr_swigregister(audio_oss_sink_sptrPtr)


audio_oss_sink_block = _audio_oss.audio_oss_sink_block
audio_oss_sink_sptr.block = lambda self: audio_oss_sink_block (self)
audio_oss_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


sink = _audio_oss.sink
class audio_oss_source_sptr(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_source_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_source_sptr, name)
    def __repr__(self):
        return "<C boost::shared_ptr<(audio_oss_source)> instance at %s>" % (self.this,)
    def __init__(self, *args):
        _swig_setattr(self, audio_oss_source_sptr, 'this', _audio_oss.new_audio_oss_source_sptr(*args))
        _swig_setattr(self, audio_oss_source_sptr, 'thisown', 1)
    def __deref__(*args): return _audio_oss.audio_oss_source_sptr___deref__(*args)
    def name(*args): return _audio_oss.audio_oss_source_sptr_name(*args)
    def input_signature(*args): return _audio_oss.audio_oss_source_sptr_input_signature(*args)
    def output_signature(*args): return _audio_oss.audio_oss_source_sptr_output_signature(*args)
    def unique_id(*args): return _audio_oss.audio_oss_source_sptr_unique_id(*args)
    def output_multiple(*args): return _audio_oss.audio_oss_source_sptr_output_multiple(*args)
    def relative_rate(*args): return _audio_oss.audio_oss_source_sptr_relative_rate(*args)
    def check_topology(*args): return _audio_oss.audio_oss_source_sptr_check_topology(*args)
    def detail(*args): return _audio_oss.audio_oss_source_sptr_detail(*args)
    def set_detail(*args): return _audio_oss.audio_oss_source_sptr_set_detail(*args)
    def __del__(self, destroy=_audio_oss.delete_audio_oss_source_sptr):
        try:
            if self.thisown: destroy(self)
        except: pass

class audio_oss_source_sptrPtr(audio_oss_source_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_oss_source_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_source_sptr, 'thisown', 0)
        _swig_setattr(self, audio_oss_source_sptr,self.__class__,audio_oss_source_sptr)
_audio_oss.audio_oss_source_sptr_swigregister(audio_oss_source_sptrPtr)


audio_oss_source_block = _audio_oss.audio_oss_source_block
audio_oss_source_sptr.block = lambda self: audio_oss_source_block (self)
audio_oss_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


source = _audio_oss.source
